# Tapioca Mailgun

## Installation
```
pip install tapioca-mailgun
```

## Documentation
``` python
from tapioca_mailgun import Mailgun


api = Mailgun(
	user='{your-user}', password='{your-password}')

```

No more documentation needed.

- Learn how Tapioca works [here](http://tapioca-wrapper.readthedocs.org/en/stable/quickstart.html)
- Explore this package using iPython
- Have fun!
